@@ -17,7 +17,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(finddeps);
 
-$VERSION = '2.32';
+$VERSION = '2.33';
 
 use constant DEFAULT02PACKAGES => 'http://www.cpan.org/modules/02packages.details.txt.gz';
 use constant MAXINT => ~0;
@@ -103,6 +103,7 @@ by default.
 
 Adds recommended modules to the list of dependencies, if set to a true value.
 
+
 =back
 
 It returns a list of CPAN::FindDependencies::Dependency objects, whose
@@ -112,15 +113,20 @@ useful methods are:
 
 =item name
 
-The module's name
+The module's name;
 
 =item distribution
 
-The distribution containing this module
+The distribution containing this module;
+
+=item version
+
+The minimum required version of his module (if specified in the requirer's
+pre-requisites list);
 
 =item depth
 
-How deep in the dependency tree this module is
+How deep in the dependency tree this module is;
 
 =item warning
 
@@ -183,7 +189,7 @@ L<http://search.cpan.org>
 
 =head1 AUTHOR, LICENCE and COPYRIGHT
 
-Copyright 2007 - 2009 David Cantrell E<lt>F<david@cantrell.org.uk>E<gt>
+Copyright 2007 - 2010 David Cantrell E<lt>F<david@cantrell.org.uk>E<gt>
 
 This software is free-as-in-speech software, and may be used,
 distributed, and modified under the terms of either the GNU
@@ -193,6 +199,8 @@ be found in the files GPL2.txt and ARTISTIC.txt, respectively.
 
 =head1 THANKS TO
 
+Brian Phillips (for the code to report on required versions of modules)
+
 Ian Tegebo (for the code to extract deps from Makefile.PL)
 
 Georg Oechsler (for the code to also list 'recommended' modules)
@@ -316,6 +324,7 @@ sub _finddeps_uncached {
             depth      => $depth,
             cpanmodule => $target,
             p          => $p,
+            version    => $version || 0,
             ($warning ? (warning => $warning) : ())
         ),
         ($depth != $opts->{maxdepth}) ? (map {
